check_character_vector: Check that a specific list element is a character vector

Description Usage Arguments

View source: R/utils_validation.R

Description

Assumes non-zero length.

Usage

1
2
3
4
5
6
7
8
9
check_character_vector(
  obj,
  attr,
  err_h,
  allowed_values = NULL,
  allow_na = FALSE,
  allow_null = FALSE,
  allow_na_last = FALSE
)

Arguments

obj

The list object, that should be checked

attr

A string holding the name of the list element, that should be checked.

err_h

An error handler.

allowed_values

An optional set of allowed strings.

allow_na

Are NA values allowed?

allow_null

A logical, defining whether the argument is allowed to be NULL.

allow_na_last

A logical value, defining if the last entry of the vector is allowed to be NA.


a-maldet/readall documentation built on Dec. 18, 2021, 9:23 p.m.