View source: R/utils_validation.R
Check that a specific list element is a logical value
1 | check_logical(obj, attr, err_h, allow_na = FALSE, allow_null = FALSE)
|
obj |
The list object, that should be checked |
attr |
A string holding the name of the list element, that should be checked. |
err_h |
An error handler. |
allow_na |
Are |
allow_null |
A logical, defining whether the argument is allowed to be |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.