Description Usage Arguments Value File types
View source: R/file_structure_methods.R
Get the specified file type
1 2 3 4 5 6 7 8 9 10 11 12 13 | get_file_type(obj, ...)
## S3 method for class 'file_structure_fwf'
get_file_type(obj, ...)
## S3 method for class 'file_structure_dsv'
get_file_type(obj, ...)
## S3 method for class 'file_structure_excel'
get_file_type(obj, ...)
## S3 method for class 'file_structure_sas'
get_file_type(obj, ...)
|
obj |
A file_structure class or a file_definition class object, that holds all informations needed for reading a specific data set. |
... |
Optional error handler |
A string holding the file type defined in obj
The function read_data() can read read four different types of data
FWF: Fixed width files. This files are text files, where the data is
stored in columns, that have a fixed character width.
DSV: Delimiter-separated value file. This files are text files, where
the data is stored in columns that are separated by a delimiter character.
EXCEL: An excel file holding the data.
SAS: A SAS file holding the data.
In order to read a data file with the function read_data(),
it is useful to create a file_definitionuration or
file_structure class object,
holding all needed data file file_structures:
new_file_definition_fwf() or new_file_structure_fwf() for FWF files
new_file_definition_dsv() or new_file_structure_dsv() for DSV files
new_file_definition_excel() or new_file_structure_excel() for Excel files
new_file_definition_sas() or new_file_structure_sas() for SAS files
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.