Description Usage Arguments Value meta information See Also
This class holds a list of col_meta class objects. For
more details about col_meta class objects see section
meta information.
file_meta class objects are usually stored in
file_structure class objects or
file_definition class objects or as attributes of data.frames.
1 |
... |
None, one or multiple col_meta class objects |
A new file_meta class object, holding all passed in col_meta class objects.
The col_meta class objects are used in order to store some
meta information about single data columns, like additional column desciptions,
and column value/level descriptions. In order to store meta information
about a set of columns a file_meta class object can be
used. This objects store a list of col_meta class objects, where
each col_meta class object corresponds to a specific column in
a data set. This file_meta class objects are usually
stored in file_structure class objects or
file_definition class objects. But when calling read_data(), the
meta information gets also appended to the resulting data.frame.
The meta information stored in a file_structure,
a file_definition class object or a read data.frame can be extracted
by using the function get_meta().
A col_meta class object holds the following informations:
desc: A string holding the column description.
values: A vector (character/logical/numeric) usually holding
the possible column values (e.g. c(1, 2)) or a more abstract text
version of the column values (e.g. c("JJJJMMDD", "99999999", "")).
values_desc: A character vector that corresponds to the values vector.
Each entry of values_desc is a more detailed description of the
corresponding entry in values. If some descriptions are not present,
the entries are NA values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.