View source: R/utils_validation.R
Assumes non-zero length.
1 2 3 4 5 6 7 8 9 |
obj |
The list object, that should be checked |
attr |
A string holding the name of the list element, that should be checked. |
err_h |
An error handler. |
allowed_values |
An optional set of allowed strings. |
allow_na |
Are |
allow_null |
A logical, defining whether the argument is allowed to be |
allow_na_last |
A logical value, defining if the last entry of the
vector is allowed to be |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.